==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitate",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your settings have been updated." : "Tu preferentias ha essite actualisate.",
    "Mail" : "Posta",
    "Stream" : "Fluxo",
    "Activity notification" : "Notification de activitate",
    "All Activities" : "Omne activitates",
    "Activities by you" : "Activitates per te",
    "Activities by others" : "Activitates per alteres",
    "in %s" : "in %s",
    "%s and %s" : "%s e %s",
    ", " : ", ",
    "_%s and %n more_::_%s and %n more_" : ["%s e %n altere","%s e %n altere"],
    "Hello %s," : "Salute %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Tu es recipente ite message de e-posta perque in le ultime hora le sequente cosas ha occurrite a %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Tu es recipente ite message de e-posta perque in le ultime die le sequente cosas ha occurrite a %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Tu es recipente ite message de e-posta perque in le ultime septimana le sequente cosas ha occurrite a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "Notifications" : "Notificationes",
    "List your own actions in the stream" : "Lista tu proprie actiones in le fluxo",
    "Notify about your own actions via email" : "Notifica super tu proprie actiones via e-posta",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Send emails:" : "Invia messages de e-posta:",
    "Hourly" : "De cata ora",
    "Daily" : "Quotidian",
    "Weekly" : "Septimanal",
    "Activity feed" : "Syndication de activitate",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No more events to load" : "Necun altere eventos de cargar",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitate",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your feed URL is invalid" : "Le URL del syndication es invalide",
    "Your settings have been updated." : "Tu preferentias ha essite actualisate.",
    "Mail" : "Posta",
    "Stream" : "Fluxo",
    "Activities" : "Activitates",
    "Error loading activities" : "Error durante le cargamento de activitates",
    "No activities" : "Nulle activitates",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Iste fluxo monstra eventos como additiones, cambiamentos e condivisiones",
    "There are no events for this filter" : "Il non ha eventos pro iste filtro",
    "Today" : "Hodie",
    "\"remote user\"" : "\"usator remote\"",
    "Activity notification" : "Notification de activitate",
    "All Activities" : "Omne activitates",
    "Activities by you" : "Activitates per te",
    "Activities by others" : "Activitates per alteres",
    "%s and %s" : "%s e %s",
    "Hello %s," : "Salute %s,",
    "You are receiving this email because the following things happened at %s" : "Tu recipe iste message perque le sequente cosas ha occurrite a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n altere ","* e %n alteres "],
    "List your own actions in the stream" : "Lista tu proprie actiones in le fluxo",
    "Notify about your own actions via email" : "Notifica super tu proprie actiones via e-posta",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Send emails:" : "Invia messages de e-posta:",
    "Hourly" : "De cata ora",
    "Daily" : "Quotidian",
    "Weekly" : "Septimanal",
    "Activity feed" : "Syndication de activitate",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No activity yet" : "Nulle activitate ancora",
    "No more events to load" : "Necun altere eventos de cargar",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");
